@@ -229,14 +229,14 @@ class MainController:
         if not self.is_ready_to_action() == 'READY':
             raise ControllerNotReady
 
-    def start_scan(self, wavelengths=None, positions=None):
+    def start_scan(self, wl_step=None, positions=None):
         self._check_ready()
         if self._scanCommandThread:
             if self._scanCommandThread.is_alive():
                 raise AlreadyScanningException
             self._scanCommandThread = None
         self._scanCommand = ScanCommand(controller=self,
-                                        wavelegths=wavelengths or get_scanning_wavelengths(),
+                                        wavelegths=get_scanning_wavelengths(wl_step),
                                         positions=positions)
         self._scanCommandThread = threading.Thread(target=self._scanCommand.execute)
         self._scanCommandThread.start()
