@@ -50,9 +50,10 @@ class ECController(BaseController):
 
     def _check_connection(self):
         try:
-            self._pulser_status = self._driver.info_xc()['response']['data']['pulser']['status']
-            self._tc_status = self._driver.info_xc()['response']['data']['tc']['status']
-            self._stage_status = self._driver.info_xc()['response']['data']['stage']['status']
+            info_xc = self._driver.info_xc()
+            self._pulser_status = info_xc['response']['data']['pulser']['status']
+            self._tc_status = info_xc['response']['data']['tc']['status']
+            self._stage_status = info_xc['response']['data']['stage']['status']
             if self._pulser_status == -1 or self._pulser_status == 2000 or self._pulser_status == 2001:
                 self._pulser_responsive = False
                 logging.error('pulser unresponsive: {}'.format(self._pulser_status))
@@ -74,24 +75,11 @@ class ECController(BaseController):
         return True
 
     def _connect(self):
-        try:
-            if self._driver is None:
-                self._driver = ECClient(base_url=self._ec_client_url)
-                self._driver.initialize_xc()
-                time.sleep(10)
-                print(self._driver.info_xc())
-                time.sleep(1)
-        except Exception as e:
-            logging.error('Could not start the device controllers {}'.format(e))
-            self._driver.shutdown_xc()
+        if self._driver is None:
+            self._driver = ECClient(base_url=self._ec_client_url)
 
     def _disconnect(self):
-        try:
-            self._driver.shutdown_xc()
-        except Exception as e:
-            logging.exception(e)
-        finally:
-            self._driver = None
+        self._driver = None
 
     def is_temp_stable(self):
         temperature_stable = self.system_info()['response']['data']['tc']['stability']
@@ -267,7 +255,6 @@ class ECClient:
 
     def move_to_wavelength(self, wl, timeout=2):
         self._post('/stage/wavelength', params={'wavelength': wl})
-        time.sleep(1.0)
         start_time = time.time()
         while True:
             status = self._get('/stage/status')['response']['code']
@@ -275,7 +262,7 @@ class ECClient:
                 break
             if time.time() - start_time > timeout:
                 raise MotorStabilizationTimeout
-            time.sleep(0.2)
+            time.sleep(max(timeout/100.0, 0.05))
 
     def stepwise_move(self, positions, delay_s):
         self._post('/stage/irrstepwise_move_wl', params=dict(positions = positions, delay_s = delay_s))
